.. _tutorial:

========
Tutorial
========

Briefcase is a packaging tool - but first you need something to package. The
best way to learn about Briefcase is to see it working with the rest of the
BeeWare suite of tools.

`The BeeWare tutorial <https://docs.beeware.org/en/latest/>`__ walks you
through the process of building a native Python application from scratch.

Once you've done that tutorial, the :doc:`Briefcase How-To Guides
<../how-to/index>` provide details on performing specific tasks with Briefcase.
